init method

  1. @override
void init([
  1. FlutterDeckState? state
])

Initializes the client with the given state.

In flutter_deck, the presentation will call this method with the initial state of the presentation. The presenter view will also call this method, but with a null state.

Implementation

@override
void init([FlutterDeckState? state]) {}