updateState method
Updates the client state with the given state.
This method is called by both the presentation and the presenter view to
keep the FlutterDeckState in sync.
Implementation
@override
void updateState(FlutterDeckState state) {}
Updates the client state with the given state.
This method is called by both the presentation and the presenter view to
keep the FlutterDeckState in sync.
@override
void updateState(FlutterDeckState state) {}