FlutterDeckWebClient class
Stub implementation of FlutterDeckClient.
This implementation does nothing and returns empty streams. It will be used when the package is imported in non-web platforms.
Constructors
Properties
-
flutterDeckStateStream
→ Stream<
FlutterDeckState> -
Returns the state as a stream of
FlutterDeckStateobjects.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Disposes the client.
-
init(
[FlutterDeckState? state]) → void -
Initializes the client with the given
state. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openPresenterView(
) → void - Opens the presenter view.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateState(
FlutterDeckState state) → void -
Updates the client state with the given
state.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited